/**
 * DiCloud - GENI project
 * 
 * (C) 2010 - University of Massachusetts Amherst
 * 
 * Initial developer(s): Emmanuel Cecchet.
 * Contributor(s): ______________________.
 */

package edu.umass.cs.geni.ec2.accounting;

import java.io.IOException;
import java.util.Properties;

/**
 * TODO: Def here
 * 
 * @author <a href="mailto:cecchet@cs.umass.edu">Emmanuel Cecchet </a>
 * @version 1.0
 * 
 */
public class AWSActivityPricing
{
  public static final double     CLOUDWATCH                  = -0.015;
  public static final Properties ec2Pricing                  = new Properties();
  static
  {
	try
	{
	  ec2Pricing.load(ClassLoader
		  .getSystemResourceAsStream("ec2pricing.properties"));
	}
	catch (Exception e)
	{
	  throw new RuntimeException(
		  "Failed to initialize EC2 pricing from ec2pricing.properties", e);
	}
  }

  public static final double     EC2_NETWORK_IN_PER_GB       = 0;
  public static final double     EC2_NETWORK_OUT_PER_GB      = -.15;

  public static final double     S3_STORAGE_PER_GB_PER_MONTH = -.15;
  public static final double     S3_PUT_OPERATION            = -.01 / 1000;
  public static final double     S3_GET_OPERATION            = -.01 / 10000;

  public static final double     EBS_IO_PER_MILLION          = -.1;

  /**
   * Return the price of an EC2 instance for the given type and region
   * (according to the definitions in ec2pricing.properties)
   * 
   * @param type
   *          EC2 instance type (m1.small | m1.large | m1.xlarge | c1.medium |
   *          c1.xlarge | m2.xlarge | m2.2xlarge | m2.4xlarge)
   * @param region
   *          EC2 region (eu-west-1|us-east-1|us-west-1|ap-southeast-1)
   * @return the corresponding price including Cloudwatch
   * @throws Exception
   *           if the price cannot be found
   * 
   */
  public static final double getEC2InstancePrice(String type, String region)
	  throws Exception
  {
	if (ec2Pricing == null)
	  throw new Exception(
		  "ec2pricing.properties missing. Cannot determine EC2 pricing.");
	try
	{
	  return Double.valueOf(ec2Pricing.getProperty(type + "," + region))
		  .doubleValue()
		  + CLOUDWATCH;
	}
	catch (RuntimeException e)
	{
	  throw new Exception("No price found for EC2 type " + type + " in region "
		  + region + ". Check ec2pricing.properties for available prices.");
	}
  }
}
